<?php
/**
 * 2007-2020 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2020 PrestaShop SA
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class ReveChat extends Module
{
    public function __construct()
    {
        $this->name = "revechat";
        $this->tab = 'front_office_features';
        $this->version = '1.0.5';
        $this->author = 'revechat';
        $this->need_instance = 0;
        $this->ps_version_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
        $this->bootstrap = true;
        $this->module_key = 'd86832c6058b23753ae20da4383f7471';

        parent::__construct();

        $this->displayName = $this->l('REVE Chat');
        $this->description = $this->l('REVE Chat is powerful and intuitive real-time customer engagement software.');
        $this->confirmUninstall = $this->l('Are you sure you want to uninstall?');

        if (!Configuration::get('REVECHAT_AID')) {
            $this->warning = $this->l('REVE Chat authentication failed');
        }
    }

    public function install()
    {
        return parent::install() &&
        $this->registerHook('header') && Configuration::updateValue('REVECHAT_AID', '');
    }

    public function uninstall()
    {
        if (!parent::uninstall() || !Configuration::deleteByName('REVECHAT_AID')) {
            return false;
        }
        return true;
    }

    public function getContent()
    {
        $output = null;
        if (((bool)Tools::isSubmit('submit-' . $this->name)) == true) {
            $revechat_aid = (string)Tools::getValue('REVECHAT_AID');

            if (!$revechat_aid || empty($revechat_aid) || !Validate::isGenericName($revechat_aid)) {
                $output .= $this->displayError($this->l('Invalid REVE Chat Login'));
            } else {
                Configuration::updateValue("REVECHAT_AID", $revechat_aid);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }
        if (((bool)Tools::isSubmit('remove-' . $this->name)) == true) {
            Configuration::updateValue("REVECHAT_AID", 0);
            $output .= $this->displayConfirmation($this->l('REVE Chat Login information removed'));
        }

        $this->context->controller->addCSS($this->_path . '/views/css/revechat_admin.css', 'all');
        $this->context->controller->addJS($this->_path . '/views/js/revechat_admin.js', 'all');
        $output .= '<p class="ajax_message"></p>';
        return $output . $this->displayForm();
    }

    public function displayForm()
    {
        // Get default language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');
        $fields_form = array();
        // Init Fields form array
        if ($this->revechatIsInstalled()) {
            $fields_form['revechat_remove_form']['form'] = array(
            'legend' => array(
              'title' => $this->l('REVE Chat Installed'),
            ),
            'submit' => array(
              'title' => $this->l('Remove'),
              'class' => 'btn btn-default',
              'id' => 'revechat_remove'
            )
            );
        } else {
            $fields_form['revechat_choose_form']['form'] = array(
            'legend' => array(
              'title' => $this->l('Already have a REVE Chat account?'),
            ),
            'input' => array(
              array(
            'type' => 'radio',
            'name' => 'revechat_choose_form',
            'required' => true,
            'class' => 'revechat_choose_form',
            'values' => array(
              array(
                'id' => 'has_revechat_account',
                'value' => 0,
                'label' => $this->l('Yes, I already have a REVE Chat account'),
              ),
              array(
                'id' => 'new_revechat_account',
                'value' => 1,
                'label' => $this->l('No, I want to create one')
              )
              ),
              ),
            )
            );
            $fields_form['revechat_already_have']['form'] = array(
            'legend' => array(
              'title' => $this->l('REVE Chat Login'),
            ),
            'input' => array(
              array(
            'type' => 'text',
            'label' => $this->l('REVE Chat Login Email'),
            'name' => 'revechat_account_email',
            'id' => 'edit-revechat-account-email',
              ),
              array(
            'type' => 'hidden',
            'label' => $this->l('REVE Chat Aid'),
            'name' => 'REVECHAT_AID',
            'value' => 0
              ),
            )
            );
            $fields_form['revechat_new_account']['form'] = array(
            'legend' => array(
              'title' => $this->l('Create New REVE Chat Account'),
            ),
            'input' => array(
              array(
            'type' => 'text',
            'label' => $this->l('Full Name'),
            'name' => 'revechat_name',
            'id' => 'revechat_name',
            ),
              array(
            'type' => 'text',
            'label' => $this->l('Work Email Address'),
            'name' => 'revechat_email',
            'id' => 'revechat_email',
            ),
              array(
            'type' => 'password',
            'label' => $this->l('Password'),
            'name' => 'revechat_password',
            'id' => 'revechat_password',
            ),
              array(
            'type' => 'text',
            'label' => $this->l('Company Website'),
            'name' => 'revechat_website',
            'id' => 'revechat_website',
            ),
              array(
            'type' => 'text',
            'label' => $this->l('Contact No'),
            'name' => 'revechat_phone',
            'id' => 'revechat_phone',
              ),
            )
            );
            $fields_form[3]['form'] = array(
            'submit' => array(
              'title' => $this->l('Save'),
              'class' => 'btn btn-default',
            )
            );
        }
        $helper = new HelperForm();
        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        if ($this->revechatIsInstalled()) {
            $helper->submit_action = 'remove-' . $this->name;
        } else {
            $helper->submit_action = 'submit-' . $this->name;
        }

        $helper->toolbar_btn = array(
        'save' =>
        array(
          'desc' => $this->l('Save'),
          'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
            '&token=' . Tools::getAdminTokenLite('AdminModules'),
        ),
        'back' => array(
        'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
        'desc' => $this->l('Back to list')
        )
        );

        // Load current value
        $helper->fields_value['REVECHAT_AID'] = Configuration::get('REVECHAT_AID');
        $helper->tpl_vars = array(
        'fields_value' => $this->getConfigFieldsValues(),
        'languages' => $this->context->controller->getLanguages(),
        'id_language' => $this->context->language->id
        );
        $form_array = $this->generateForm($fields_form);
        return $helper->generateForm($form_array);
    }
    private function generateForm($fields_form = array())
    {
        $form_array = array();
        foreach ($fields_form as $key => $value) {
            $form_array[$key] = $value;
        }
        return $form_array;
    }
    private function revechatIsInstalled()
    {
        $revechat_aid = Configuration::get('REVECHAT_AID');
        if (empty($revechat_aid)) {
            return false;
        } elseif (!empty($revechat_aid)) {
            return true;
        }
    }

    public function getConfigFieldsValues()
    {
        return array(
        'revechat_choose_form' => "",
        'revechat_account_email' => "",
        'revechat_name' => "",
        'revechat_email' => "",
        'revechat_phone' => "",
        'install_success' => "",
        'REVECHAT_AID' => Configuration::get('REVECHAT_AID'),
        );
    }

    public function hookDisplayHeader()
    {
        $this->context->smarty->assign(
            array(
            'revechat_aid' => Configuration::get('REVECHAT_AID'),
            )
        );
        return $this->display(__FILE__, 'revechat.tpl');
    }
}
